check_na_rate: Check the NA value rate for each column in a dataframe

Description Usage Arguments Value

Description

Check the NA value rate for each column in a dataframe

Usage

1

Arguments

x

a data frame

Value

a data frame with variable name and the NA rate


tianwei-zhang/tianweiR documentation built on May 21, 2019, 3:03 a.m.