chi_sq_test_df: Apply chi-square test for any combination of two columns in a...

Description Usage Arguments Value Examples

Description

Apply chi-square test for any combination of two columns in a data set

Usage

1

Arguments

data

A dataframe whose columns will be tested for chi-square indepedence.

Value

a matrix with the p-values of the chi-square test. Each column or row represents a variable in the input dataframe

Examples

1

tianwei-zhang/tianweiR documentation built on May 21, 2019, 3:03 a.m.