Description Usage Arguments Value Examples
Normalize a continuous variable to a binary varibale based on median
1 | normalize_numeric_2_binary(data, col_to_change, comparator)
|
data |
a dataframe with some numeric columns |
col_to_change |
column index to change from nuermic to binary |
comparator |
> or >= median |
a dataframe with changed columns
1 | normalize_numeric_2_binary(iris,c(1,2),'>')
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.