Description Usage Arguments Value Examples
Apply chi-square test for any combination of two columns in a data set
1 |
data |
A dataframe whose columns will be tested for chi-square indepedence. |
a matrix with the p-values of the chi-square test. Each column or row represents a variable in the input dataframe
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.